# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _vnl_least_squares_functionPython
else:
    import _vnl_least_squares_functionPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_vectorPython
class vnl_least_squares_function(object):
    r"""Proxy of C++ vnl_least_squares_function class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    UseGradient_no_gradient = _vnl_least_squares_functionPython.vnl_least_squares_function_UseGradient_no_gradient
    
    UseGradient_use_gradient = _vnl_least_squares_functionPython.vnl_least_squares_function_UseGradient_use_gradient
    
    __swig_destroy__ = _vnl_least_squares_functionPython.delete_vnl_least_squares_function

    def throw_failure(self):
        r"""throw_failure(self)"""
        return _vnl_least_squares_functionPython.vnl_least_squares_function_throw_failure(self)

    def clear_failure(self):
        r"""clear_failure(self)"""
        return _vnl_least_squares_functionPython.vnl_least_squares_function_clear_failure(self)

    def f(self, x, fx):
        r"""
        f(self, x, fx)

        Parameters
        ----------
        x: vnl_vectorD const &
        fx: vnl_vectorD &

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_f(self, x, fx)

    def gradf(self, x, jacobian):
        r"""
        gradf(self, x, jacobian)

        Parameters
        ----------
        x: vnl_vectorD const &
        jacobian: vnl_matrixD &

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_gradf(self, x, jacobian)

    def fdgradf(self, x, jacobian, stepsize):
        r"""
        fdgradf(self, x, jacobian, stepsize)

        Parameters
        ----------
        x: vnl_vectorD const &
        jacobian: vnl_matrixD &
        stepsize: double

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_fdgradf(self, x, jacobian, stepsize)

    def ffdgradf(self, x, jacobian, stepsize):
        r"""
        ffdgradf(self, x, jacobian, stepsize)

        Parameters
        ----------
        x: vnl_vectorD const &
        jacobian: vnl_matrixD &
        stepsize: double

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_ffdgradf(self, x, jacobian, stepsize)

    def trace(self, iteration, x, fx):
        r"""
        trace(self, iteration, x, fx)

        Parameters
        ----------
        iteration: int
        x: vnl_vectorD const &
        fx: vnl_vectorD const &

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_trace(self, iteration, x, fx)

    def rms(self, x):
        r"""
        rms(self, x) -> double

        Parameters
        ----------
        x: vnl_vectorD const &

        """
        return _vnl_least_squares_functionPython.vnl_least_squares_function_rms(self, x)

    def get_number_of_unknowns(self):
        r"""get_number_of_unknowns(self) -> unsigned int"""
        return _vnl_least_squares_functionPython.vnl_least_squares_function_get_number_of_unknowns(self)

    def get_number_of_residuals(self):
        r"""get_number_of_residuals(self) -> unsigned int"""
        return _vnl_least_squares_functionPython.vnl_least_squares_function_get_number_of_residuals(self)

    def has_gradient(self):
        r"""has_gradient(self) -> bool"""
        return _vnl_least_squares_functionPython.vnl_least_squares_function_has_gradient(self)

# Register vnl_least_squares_function in _vnl_least_squares_functionPython:
_vnl_least_squares_functionPython.vnl_least_squares_function_swigregister(vnl_least_squares_function)

